%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}

%define expat_version           2.0.1

%define lib_major 3
%define lib_api 1
%define lib_name %mklibname dbus %{lib_api} %{lib_major}
%define develname %mklibname -d dbus

%define enable_test 0
%define enable_verbose 0

%define git_url git://git.freedesktop.org/git/dbus/dbus

Summary: D-Bus message bus
Name: dbus
Version: 1.6.18
Release: %mkrel 1
URL: http://www.freedesktop.org/Software/dbus
Source0: http://dbus.freedesktop.org/releases/dbus/%{name}-%{version}.tar.gz
# (cg) See https://bugs.freedesktop.org/show_bug.cgi?id=56043
Patch100: 0100-dbus-spawn-set-SIGPIPE-to-SIG_IGN-before-activating-.patch
Patch101: 0101-Add-support-for-systems-without-syslog.h.patch
Patch102: 0102-sysdeps-Don-t-use-LOG_PERROR-if-systemd-is-booted.patch
Patch103: 0103-Do-not-suppress-syslog-test-s-stderr-just-because-in.patch
Patch104: 0104-dbus-make_and_run_test_nodes-avoid-undefined-behaviour.patch
Patch105: 0105-dbus-fixed-memory-freeing-if-error-during-listing-service.patch
License: GPLv2+ or AFL
Group: System/Servers
BuildRequires: libx11-devel
BuildRequires: expat-devel >= %{expat_version}
%if !%bootstrap
BuildRequires: xmlto docbook-dtd412-xml
BuildRequires: doxygen
%endif
BuildRequires: libtool
BuildRequires: libcap-ng-devel
BuildRequires: pkgconfig(gio-2.0) >= 2.24
BuildRequires: pkgconfig(glib-2.0) >= 2.24
BuildRequires: pkgconfig(libsystemd-daemon) >= 32
BuildRequires: pkgconfig(libsystemd-login) >= 32
Requires(pre): shadow-utils
Requires(preun): rpm-helper >= 0.24.8-1
Provides: should-restart = system

%description
D-Bus is a system for sending messages between applications. It is
used both for the systemwide message bus service, and as a
per-user-login-session messaging facility.

%package -n %{lib_name}
Summary: Shared library for using D-Bus
Group: System/Libraries
Requires: dbus >= %{version}
Obsoletes: %{_lib}dbus-1_3 < 1.6.0

%description -n %{lib_name}
D-Bus shared library.

%package -n %develname
Summary: Libraries and headers for D-Bus
Group: Development/C
Requires: %{name} = %{version}
Requires: %{lib_name} = %{version}
Provides: lib%{name}-1-devel = %{version}-%{release}
Provides: lib%{name}-devel = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}
Conflicts: %{_lib}dbus-1_0-devel
Obsoletes: %{mklibname -d dbus- 1 3} < 1.6.0
Obsoletes: %{_lib}dbus-1-devel < 1.6.0

%description -n %develname
Headers and static libraries for D-Bus.

%package x11
Summary: X11-requiring add-ons for D-Bus
Group: System/Servers
Requires: dbus = %{version}

%package doc
Summary: Developer documentation for D-BUS
Group: Documentation
Requires: dbus = %{version}
Suggests: devhelp
BuildArch: noarch
Conflicts: libdbus-1-devel < 1.2.20
Conflicts: lib64dbus-1-devel < 1.2.20

%description doc 
This package contains developer documentation for D-Bus along with
other supporting documentation such as the introspect dtd file.

%description x11
D-Bus contains some tools that require Xlib to be installed, those are
in this separate package so server systems need not install X.

%prep
%setup -q
%apply_patches

%build

COMMON_ARGS="--disable-static --disable-selinux --with-system-socket=/run/dbus/system_bus_socket --libexecdir=%{_libexecdir}/dbus-%{lib_api}" 

#### Build once with tests to make check
%if %{enable_test}
%configure2_5x $COMMON_ARGS --enable-tests=yes --enable-systemd \
               --enable-verbose-mode=yes \
               --enable-asserts=yes \
               --disable-doxygen-docs \
               --enable-userdb-cache \
               --disable-xml-docs
DBUS_VERBOSE=1 %make
make check

#### Clean up and build again 
make clean
%endif 

%configure2_5x $COMMON_ARGS --disable-tests --disable-asserts \
%if !%bootstrap
 --enable-doxygen-docs --enable-xml-docs \
 --htmldir=%{_datadir}/devhelp/books/%{name} \
%endif
%if %enable_verbose
 --enable-verbose-mode=yes
%else 
 --enable-verbose-mode=no
%endif
%make

%check
make check

%install
%makeinstall_std

mkdir -p %{buildroot}%{_sysconfdir}/X11/xinit.d
cat << EOF > %{buildroot}%{_sysconfdir}/X11/xinit.d/30dbus
# to be sourced
if [ -z "\$DBUS_SESSION_BUS_ADDRESS" ]; then
  eval \`/usr/bin/dbus-launch --exit-with-session --sh-syntax\`
fi
EOF
chmod 755 %{buildroot}%{_sysconfdir}/X11/xinit.d/30dbus

# create directory
mkdir %{buildroot}%{_datadir}/dbus-%{lib_api}/interfaces

# This is legacy
rm -rf %{buildroot}%{_unitdir}/dbus.target.wants

# link devhelp docs in docdir
mkdir -p %{buildroot}%{_docdir}/%{name}-doc
pushd %{buildroot}%{_datadir}/devhelp/books/%{name}
for f in *; do
  ln -s ../../devhelp/books/%{name}/$f %{buildroot}%{_docdir}/%{name}-doc
done
popd

#remove unpackaged file
find %{buildroot} -name '*.la' -delete

%pre
# (cg) Do not require/use rpm-helper helper macros... we must do this manually
# to avoid dep loops during install
/usr/sbin/groupadd -r messagebus 2>/dev/null || :
/usr/sbin/useradd -r -c "system user for %{name}" -g messagebus -s /sbin/nologin -d / messagebus 2>/dev/null || :

%postun
%_postun_userdel messagebus
%_postun_groupdel messagebus

%files
%doc COPYING NEWS
%dir %{_sysconfdir}/dbus-%{lib_api}
%exclude %{_sysconfdir}/rc.d/init.d/*
%config(noreplace) %{_sysconfdir}/dbus-%{lib_api}/*.conf
%dir %{_sysconfdir}/dbus-%{lib_api}/system.d
%dir %{_sysconfdir}/dbus-%{lib_api}/session.d
%dir %{_localstatedir}/lib/dbus
%dir %{_libdir}/dbus-1.0
%{_bindir}/dbus-daemon
%{_bindir}/dbus-send
%{_bindir}/dbus-cleanup-sockets
%{_bindir}/dbus-uuidgen
%{_mandir}/man*/*
%dir %{_datadir}/dbus-%{lib_api}
%{_datadir}/dbus-%{lib_api}/system-services
%{_datadir}/dbus-%{lib_api}/services
%{_datadir}/dbus-%{lib_api}/interfaces
# See doc/system-activation.txt in source tarball for the rationale
# behind these permissions
%dir %{_libexecdir}/dbus-%{lib_api}
%attr(4750,root,messagebus) %{_libexecdir}/dbus-%{lib_api}/dbus-daemon-launch-helper
%{_unitdir}/dbus.service
%{_unitdir}/dbus.socket
%{_unitdir}/multi-user.target.wants/dbus.service
%{_unitdir}/sockets.target.wants/dbus.socket

%files -n %{lib_name}
%{_libdir}/*dbus-%{lib_api}*.so.%{lib_major}*

%files -n %develname
%doc ChangeLog 
%{_libdir}/libdbus-%{lib_api}.so
%{_libdir}/dbus-1.0/include
%{_libdir}/pkgconfig/dbus-%{lib_api}.pc
%{_includedir}/dbus-1.0

%files x11
%{_sysconfdir}/X11/xinit.d/*
%{_bindir}/dbus-launch
%{_bindir}/dbus-monitor

%files doc
%doc %{_datadir}/devhelp/books/dbus
%{_docdir}/%{name}-doc


%changelog
* Tue Jan 14 2014 tmb <tmb> 1.6.18-1.mga4
+ Revision: 566552
- make_and_run_test_nodes: avoid undefined behaviour
- fixed memory freeing if error during listing services
- update to 1.6.18 (maintenance release)

* Fri Dec 20 2013 colin <colin> 1.6.12-4.mga4
+ Revision: 559096
- Add some upstream patches to prevent double logging of dbus log messages

* Thu Oct 31 2013 colin <colin> 1.6.12-3.mga4
+ Revision: 548133
- Drop pre-script requires on rpm-helper to break dep loops
- Drop adding messagebus user to daemon group - it doesn't work/isn't needed

* Sat Oct 19 2013 umeabot <umeabot> 1.6.12-2.mga4
+ Revision: 527909
- Mageia 4 Mass Rebuild

* Thu Jun 13 2013 colin <colin> 1.6.12-1.mga4
+ Revision: 442892
- New version: 1.6.12

* Sun Jun 09 2013 fwang <fwang> 1.6.10-1.mga4
+ Revision: 441024
- new version 1.6.10

* Mon Mar 11 2013 colin <colin> 1.6.8-4.mga3
+ Revision: 402096
- Require rpm-helper for pre-install scripts (mga#9326)
- Drop useless Requires(post) as there are not post scripts

* Fri Jan 11 2013 umeabot <umeabot> 1.6.8-3.mga3
+ Revision: 348634
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 25 2012 colin <colin> 1.6.8-2.mga3
+ Revision: 321915
- Drop the 'messagebus' alias for dbus.service
- Drop no longer needed/useful preun script
- Drop no longer needed/useful post script
- Drop very old upgrade triggers
- Remove reference to legacy dbus.target
- Tidy up unneeded arguments
- Don't package /var/run/dbus dir (created by systemd when starting dbus.socket)

* Tue Oct 16 2012 colin <colin> 1.6.8-1.mga3
+ Revision: 307295
- New version: 1.6.8
- Add patch to re-ignore SIGPIPE when launching services (might help gnome-shell unlock mga#7687)

* Sun Oct 14 2012 ennael <ennael> 1.6.4-2.mga3
+ Revision: 305352
- Documentation group

* Wed Sep 12 2012 fwang <fwang> 1.6.4-1.mga3
+ Revision: 292495
- new verison 1.6.4
- we do not rely libs to be put in /lib now
- new version 1.6.4

* Thu Aug 09 2012 tv <tv> 1.6.0-2.mga3
+ Revision: 280297
- fix file list
- drop sysv service

* Fri Jun 15 2012 fwang <fwang> 1.6.0-1.mga3
+ Revision: 260701
- update file list
- New version 1.6.0

* Mon Apr 30 2012 blino <blino> 1.4.16-5.mga2
+ Revision: 234333
- do not install html doc in main package, it wastes space on live CDs
- use upstream way of installing docs and drop doxygen_to_devhelp.xsl
  (available since D-Bus 1.4.14, 2011-07-29)

* Sat Apr 28 2012 tmb <tmb> 1.4.16-4.mga2
+ Revision: 233662
- Require rpm-helper >= 0.24.8-1 for systemd support

* Sat Apr 28 2012 tmb <tmb> 1.4.16-3.mga2
+ Revision: 233558
- rebuild for versioned rpm-helper requires

* Fri Apr 06 2012 colin <colin> 1.4.16-2.mga2
+ Revision: 229297
- Drop dbus.target. No longer used in systemd

* Sat Sep 24 2011 fwang <fwang> 1.4.16-1.mga2
+ Revision: 147228
- new verrsion 1.4.16

* Wed Sep 14 2011 tmb <tmb> 1.4.14-3.mga2
+ Revision: 143580
- restore 'fix initscript to not print message when systemd is absent'
  that got dropped in last version upgrade

* Fri Sep 09 2011 tv <tv> 1.4.14-2.mga2
+ Revision: 141725
- really protect '$'

* Thu Sep 08 2011 tv <tv> 1.4.14-1.mga2
+ Revision: 141550
- new release
- enable-userdb-cache
- BuildRequires: glib2-devel
- patch 7: synchronize dbus.service and dbus.target (andrey borzenkov)
- protect '$' in xinit.d here-script
- use %%buildroot macro

* Sat Jul 16 2011 cjw <cjw> 1.4.12-1.mga2
+ Revision: 124706
- 1.4.12
- drop patch6: fixed upstream
- enable systemd support

  + rtp <rtp>
    - alloc to build dbus without xml and doxygen docs.

* Fri Feb 11 2011 misc <misc> 1.4.1-3.mga1
+ Revision: 50073
- fix initscript to not print message when systemd is absent

* Tue Jan 25 2011 dmorgan <dmorgan> 1.4.1-2.mga1
+ Revision: 39177
- Fix file list
- Fix typo
- Bump release
- Merge mdv commits 631203 631334 and 631460

* Wed Jan 12 2011 dmorgan <dmorgan> 1.4.1-1.mga1
+ Revision: 7690
- Remove mdv macros

  + blino <blino>
    - imported package dbus


* Tue Dec 21 2010 Götz Waschk <waschk@mandriva.org> 1.4.1-1mdv2011.0
+ Revision: 623627
- update to new version 1.4.1

* Tue Sep 14 2010 Götz Waschk <waschk@mandriva.org> 1.4.0-1mdv2011.0
+ Revision: 578250
- update to new version 1.4.0

* Wed Mar 24 2010 Frederic Crozat <fcrozat@mandriva.com> 1.2.24-1mdv2010.1
+ Revision: 527107
- Release 1.2.24

* Wed Mar 17 2010 Frederic Crozat <fcrozat@mandriva.com> 1.2.22-1mdv2010.1
+ Revision: 524365
- Release 1.2.22
- Remove patches 7, 8 (merged upstream)

* Mon Mar 15 2010 Frederic Crozat <fcrozat@mandriva.com> 1.2.20-4mdv2010.1
+ Revision: 519138
- Patch7 (GIT): fix watch handling with threaded applications (Michael Meeks)
- Patch8 (GIT): fix build with libcap-ng enabled but selinux disabled
- build with libcap-ng enabled

* Sun Feb 07 2010 Funda Wang <fwang@mandriva.org> 1.2.20-3mdv2010.1
+ Revision: 501593
- currently youri-upload does not support uploading mixed arch packages
  at once. so dbus-doc should remain arch-dependent.

* Sat Feb 06 2010 Götz Waschk <waschk@mandriva.org> 1.2.20-2mdv2010.1
+ Revision: 501419
- rebuild for lost binary packages

* Fri Feb 05 2010 Funda Wang <fwang@mandriva.org> 1.2.20-1mdv2010.1
+ Revision: 501080
- fix group

  + Frederic Crozat <fcrozat@mandriva.com>
    - Release 1.2.20
    - Remove patches 11 & 12 (merged upstream)
    - Move documentation to seperate subpackage (Mdv bug #55360)

* Mon Oct 05 2009 Frederic Crozat <fcrozat@mandriva.com> 1.2.16-2mdv2010.0
+ Revision: 454014
- Patch16 (GIT): fix timeout handling

* Mon Jul 27 2009 Frederic Crozat <fcrozat@mandriva.com> 1.2.16-1mdv2010.0
+ Revision: 400625
- Release 1.2.16

* Tue May 12 2009 Frederic Crozat <fcrozat@mandriva.com> 1.2.4.6permissive-1mdv2010.0
+ Revision: 374914
- Release 1.2.4.6permissive
- Fix git_url

* Thu Feb 05 2009 Frederic Crozat <fcrozat@mandriva.com> 1.2.4.4permissive-2mdv2009.1
+ Revision: 337873
- Add support for runlevel 7

* Thu Jan 15 2009 Götz Waschk <waschk@mandriva.org> 1.2.4.4permissive-1mdv2009.1
+ Revision: 330046
- update to new version 1.2.4.4permissive

* Wed Oct 15 2008 Götz Waschk <waschk@mandriva.org> 1.2.4-1mdv2009.1
+ Revision: 293963
- update to new version 1.2.4

* Tue Aug 19 2008 Olivier Blin <oblin@mandriva.com> 1.2.3-2mdv2009.0
+ Revision: 273673
- depend on network-auth service instead of network-up (not to slow down boot when auth does not require network)

* Thu Aug 07 2008 Frederic Crozat <fcrozat@mandriva.com> 1.2.3-1mdv2009.0
+ Revision: 265858
- Release 1.2.3
- Remove patches 7, 8, 9, 10, 12, 13 (merged upstream)

* Fri Jul 18 2008 Frederic Crozat <fcrozat@mandriva.com> 1.2.1-4mdv2009.0
+ Revision: 238250
- Patch7 (GIT): really enable userdb cache (fd.o bug #15588)
- Patch8 (GIT): cleanup guid-less connections correctly (fd.o bug #15571)
- Patch9 (GIT): Hold a reference during read/write dispatch (fd.o bug #15635)
- Patch10 (GIT): Reset initialized state on dbus_shutdown (fd.o bug #15570)
- Patch11 (GIT): increase default method timeout (Fedora)
- Patch12 (GIT): fix crash on timers leak (fd.o #15684)
- Patch13 (GIT): add API to change session bus environment variables (fd.o bug #16669)
- Update session launcher script to not start session bus if session bus variable is already set (Fedora)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Fri May 09 2008 Götz Waschk <waschk@mandriva.org> 1.2.1-3mdv2009.0
+ Revision: 205044
- call dbus-uuidgen in post to work around bug #40700

* Wed May 07 2008 Frederic Crozat <fcrozat@mandriva.com> 1.2.1-2mdv2009.0
+ Revision: 202805
- Fix level for initscript when not using parallel init

* Wed Apr 16 2008 Frederic Crozat <fcrozat@mandriva.com> 1.2.1-1mdv2009.0
+ Revision: 194692
- Release 1.2.1
- Remove patch7 (merged upstream)

* Fri Mar 28 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.20-5mdv2008.1
+ Revision: 190832
- Clean up devel package to not package 47MB of unused documentation

* Thu Mar 27 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.20-4mdv2008.1
+ Revision: 190617
- Patch7 : fix inotify monitoring, being too agressive
- Add easy way to enable verbose mode in specfile

* Tue Mar 25 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.20-3mdv2008.1
+ Revision: 189973
- Update patch0 to add soft dependency on network service at startup

* Tue Mar 04 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.20-2mdv2008.1
+ Revision: 178271
- should-restart is a provides, not a suggests

* Wed Feb 27 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.20-1mdv2008.1
+ Revision: 175910
- Release 1.1.20
- Remove patch7, merged upstream
- no longer restart system bus, rely on should-start = system
- not use rpm-helper for adding service to prevent restarting system bus

* Wed Feb 20 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.4-3mdv2008.1
+ Revision: 173247
-Own some directories (might fix Mdv bug #37567)

  + Thierry Vignaud <tv@mandriva.org>
    - fix spacing at top of description

* Wed Feb 06 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.4-2mdv2008.1
+ Revision: 163029
- Patch7 (Fedora): fix dbus not always exiting after X shutdown

* Fri Jan 18 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.4-1mdv2008.1
+ Revision: 154583
- Release 1.1.4
- remove patch7, merged upstream

* Thu Jan 17 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.3-2mdv2008.1
+ Revision: 154280
-Patch 7 (Timo Hoenig): fix inotify backend to not DoS system on upgrade

* Wed Jan 16 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.3-1mdv2008.1
+ Revision: 153648
- Release 1.1.3
- Remove patches 1, 2, 4, 5 (merged upstream)
- Regenerate patch0 (partially merged)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Dec 14 2007 Frederic Crozat <fcrozat@mandriva.com> 1.1.2-4mdv2008.1
+ Revision: 120079
- Disable checks (don't pass on x86-64)
- Clean specfile
- Remove unapproved patch

  + Paulo Andrade <pcpa@mandriva.com.br>
    - This is a "noop" patch. But it can be considered a list of the functions,
      code from X Server uses from dbus (libdbus-1), at a later stage, this library
      can be changed to make available only the public symbols.

* Fri Nov 16 2007 Frederic Crozat <fcrozat@mandriva.com> 1.1.2-3mdv2008.1
+ Revision: 109158
- Disable patch3 (disable fatal warnings on check) for cooker, to detect buggy usage of DBus

* Mon Oct 15 2007 Götz Waschk <waschk@mandriva.org> 1.1.2-2mdv2008.1
+ Revision: 98605
- new devel name

* Mon Oct 15 2007 Frederic Crozat <fcrozat@mandriva.com> 1.1.2-1mdv2008.1
+ Revision: 98570
- Remove patch4, merged upstream
- Patch4 (Fedora): fix arborting (fd.o bug #12430)
- Patch5 (git): fix PIE usage
- Patch6 (Fedora): generate xml doc
- Package devel help in devhelp format

* Tue Sep 11 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-10mdv2008.0
+ Revision: 84492
- Add requires(post) on lib package in main package (Mdv bug #31876)

  + Thierry Vignaud <tv@mandriva.org>
    - replace %%{_datadir}/man by %%{_mandir}!

* Thu Aug 16 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-9mdv2008.0
+ Revision: 64326
- Patch4 (CVS): various bug fixes

* Thu Jul 12 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-8mdv2008.0
+ Revision: 51613
- enable dbus for runlevel 2

* Wed Jul 11 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-7mdv2008.0
+ Revision: 51319
- Enforce dependency of lib package on main package, just in case a program
  is linked to libdbus but doesn't requires dbus package

* Thu Jun 07 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.2-6mdv2008.0
+ Revision: 36905
- rebuild for expat


* Tue Mar 20 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-5mdv2007.1
+ Revision: 147000
- Patch3 (Debian): disable fatal warnings on check by default

* Mon Mar 19 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.0.2-4mdv2007.1
+ Revision: 146591
- bump release
- no need to package big ChangeLog when NEWS is already there

* Tue Jan 23 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-3mdv2007.1
+ Revision: 112518
- Disable assertion and tests for packaged binaries. Build assertions and tests at compile time
  to check if everything is ok

* Wed Dec 13 2006 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-2mdv2007.1
+ Revision: 96425
- Release 1.0.2
  Remove patch3 (merged upstream)

* Thu Nov 23 2006 Frederic Crozat <fcrozat@mandriva.com> 1.0.1-2mdv2007.1
+ Revision: 86697
- Force rebuild
- Rebuild
- Release 1.0.1
- Patch1: add inotify support
- Patch2: fix config file creation notification with dnotify
- Patch3 (CVS): fix assertion

* Fri Nov 10 2006 Götz Waschk <waschk@mandriva.org> 1.0.0-1mdv2007.0
+ Revision: 80522
- new version

* Sat Nov 04 2006 Götz Waschk <waschk@mandriva.org> 0.95-1mdv2007.1
+ Revision: 76480
- new version
- drop patch 1
- drop uuidgen workaround
- create /var/lib/dbus directory

* Sun Oct 29 2006 Götz Waschk <waschk@mandriva.org> 0.94-9mdv2007.1
+ Revision: 73643
- rebuild
- add fix for upstream bug 8780

* Wed Oct 25 2006 Götz Waschk <waschk@mandriva.org> 0.94-7mdv2007.0
+ Revision: 72405
- bot rebuild
- fix permissions of the machine-id file
- call dbus-uuidgen in postinstallation (bug #26723)

* Wed Oct 18 2006 Götz Waschk <waschk@mandriva.org> 0.94-4mdv2007.0
+ Revision: 65799
- rename system socket (gnome bug #362601)

* Tue Oct 17 2006 Götz Waschk <waschk@mandriva.org> 0.94-3mdv2006.0
+ Revision: 65533
- fix buildrequires
- fix buildrequires
  update file list
- Import dbus

* Tue Oct 17 2006 Gtz Waschk <waschk@mandriva.org> 0.94-1mdv2007.1
- update file list
- drop patches 1,2
- New version 0.94

* Fri Sep 01 2006 Gtz Waschk <waschk@mandriva.org> 0.92-6mdv2007.0
- fix buildrequires

* Wed Aug 30 2006 Frederic Crozat <fcrozat@mandriva.com> 0.92-5mdv2007.0
- Enable asserts and verbose mode, since dbus isn't 1.0 yet (J5)

* Wed Aug 30 2006 Frederic Crozat <fcrozat@mandriva.com> 0.92-4mdv2007.0
- Patch1 (CVS): fix vtable crash
- Patch2: trap SIGTERM to be able to kill session bus (Mdv bug #22143)

* Fri Aug 25 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.92-3
- fix xinit.d script to use sh-syntax, since it is always sourced by /bin/sh

* Fri Aug 25 2006 Olivier Blin <blino@mandriva.com> 0.92-2mdv2007.0
- prefix the xinit.d script with a 2 digit number
- the xinit.d script is not a config file

* Tue Aug 22 2006 Frederic Crozat <fcrozat@mandriva.com> 0.92-1mdv2007.0
- Release 0.92
- remove patch1 (merged upstream)

* Fri Aug 18 2006 Frederic Crozat <fcrozat@mandriva.com> 0.91-5mdv2007.0
- Patch1 (CVS): fix threads deadlock

* Thu Aug 10 2006 Gtz Waschk <waschk@mandriva.org> 0.91-4mdv2007.0
- fix the patch again

* Thu Aug 10 2006 Gtz Waschk <waschk@mandriva.org> 0.91-3mdv2007.0
- update patch with a fix for bug #21935

* Tue Aug 08 2006 Gtz Waschk <waschk@mandriva.org> 0.91-2mdv2007.0
- fix buildrequires

* Wed Jul 19 2006 Frederic Crozat <fcrozat@mandriva.com> 0.90-1mdv2007.0
- Release 0.90
- Remove bindings (packaged seperately now)
- Add conflicts to ease upgrade from 2006.0

* Wed Jul 19 2006 Gtz Waschk <waschk@mandriva.org> 0.62-5mdv2007.0
- remove some useless static libs
- fix postun script of the sharp package

* Thu Jun 22 2006 Gtz Waschk <waschk@mandriva.org> 0.62-4mdv2007.0
- don't depend on kdelibs

* Thu Jun 15 2006 Frederic Crozat <fcrozat@mandriva.com> 0.62-3mdv2007.0
- Regenerate patch0 and merge patch1 in it
- add strict rules for lib major in file list
- fix localstatedir location (Mdv bug #23107)

* Wed Jun 14 2006 Frederic Crozat <fcrozat@mandriva.com> 0.62-2mdv2007.0
- Rebuild with correct major for qt

* Tue Jun 13 2006 Frederic Crozat <fcrozat@mandriva.com> 0.62-1mdv2007.0
- Release 0.62
- Remove patch2 (merged upstream)

* Wed May 10 2006 Gtz Waschk <waschk@mandriva.org> 0.61-5mdk
- fix dbus-sharp pkgconfig file for x86_64

* Fri May 05 2006 Gtz Waschk <waschk@mandriva.org> 0.61-4mdk
- fix x86_64 build

* Tue Apr 25 2006 Gtz Waschk <waschk@mandriva.org> 0.61-3mdk
- fix postun of the sharp package

* Sat Apr 22 2006 Gtz Waschk <waschk@mandriva.org> 0.61-2mdk
- merge sharp bindings

* Tue Feb 28 2006 Frederic Crozat <fcrozat@mandriva.com> 0.61-1mdk
- Release 0.61
- Remove patch2, no longer needed
- Patch2: allow to disable QT4 binding

* Thu Jan 26 2006 Michael Scherer <misc@mandriva.org> 0.60-2mdk
- fix missing Requires on python binding ( thanks Christiaan Welvaart )

* Wed Jan 25 2006 Frederic Crozat <fcrozat@mandriva.com> 0.60-1mdk
- Release 0.60
- Regenerate patch2
- Remove patch3 (merged upstream)

* Mon Jan 09 2006 Olivier Blin <oblin@mandriva.com> 0.50-7mdk
- convert parallel init to LSB

* Fri Jan 06 2006 Oden Eriksson <oeriksson@mandriva.com> 0.50-6mdk
- drop selinux support

* Thu Jan 05 2006 Frederic Crozat <fcrozat@mandriva.com> 0.50-5mdk
- use mkrel
- fix buildrequires

* Mon Jan 02 2006 Olivier Blin <oblin@mandriva.com> 0.50-4mdk
- Patch1: parallel init support

* Tue Dec 27 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.50-3mdk
- patch3: use $(LIBTOOL) in Makefile.am
- fix URL

* Mon Nov 07 2005 Frederic Crozat <fcrozat@mandriva.com> 0.50-2mdk
- Enforce sub package dependency (found by till)

* Wed Oct 26 2005 Frederic Crozat <fcrozat@mandriva.com> 0.50-1mdk
- Release 0.50
- Remove patches 3, 5 (merged upstream)

* Tue Sep 13 2005 Gtz Waschk <waschk@mandriva.org> 0.23.4-5mdk
- move qt headers to the right package
- replace prereq

* Fri Sep 02 2005 Götz Waschk <waschk@mandriva.org> 0.23.4-4mdk
- rebuild to remove glitz dep

* Thu Aug 18 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.23.4-3mdk
- enable possibility to build without qt/kde stuff

* Sat Apr 30 2005 Gtz Waschk <waschk@mandriva.org> 0.23.4-2mdk
- add provides to the libdbus-glib package

* Sat Apr 23 2005 Gtz Waschk <waschk@mandriva.org> 0.23.4-1mdk
- drop patch 6
- New release 0.23.4

* Tue Mar 01 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.23.2-2mdk 
- Patch6 (CVS): fix python binding

* Wed Feb 23 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.23.2-1mdk 
- Release 0.23.2
- Remove patch4 (merged upstream)

* Wed Feb 16 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.23.1-1mdk 
- Release 0.23.1
- Patch5 (CVS): fix crash when setting group policy

* Wed Feb 16 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.23-5mdk 
- Move dbus xinit launcher in dbus-x11 package (Mdk bug #13075)

* Wed Feb 09 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.23-4mdk
- let devel symlinks stay in standard libdir

* Tue Feb 08 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.23-3mdk 
- Patch3 (Fedora): allow uid/gid to identify user/group
- Patch4 (Fedora): restrict connection to user session bus to owner or root

* Fri Jan 21 2005 Gtz Waschk <waschk@linux-mandrake.com> 0.23-2mdk
- add missing directory

* Thu Jan 20 2005 Gtz Waschk <waschk@linux-mandrake.com> 0.23-1mdk
- drop patches 1,3
- update source URL
- New release 0.23

* Wed Dec 08 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 0.22-7mdk 
- automatically start dbus when starting a X11 session

* Sun Dec 05 2004 Michael Scherer <misc@mandrake.org> 0.22-6mdk
- Rebuild for new python

* Mon Nov 15 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.22-5mdk
- add BuildRequires: kdelibs-devel

* Fri Nov 12 2004 Gtz Waschk <waschk@linux-mandrake.com> 0.22-4mdk
- create Qt development package

* Fri Oct 01 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.22-3mdk
- explicitly disable Mono bindings

* Fri Oct 01 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.22-2mdk
- fix detection of moc path
- merge in RH in64 fix for python bindings

* Sat Aug 14 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 0.22-1mdk
- Release 0.22
- Remove patch1 (merged upstream)
- enable libtoolize 
- Patch1 (Fedora): add console policy

* Tue Aug 10 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 0.21-4mdk
- Update patch 20 to change start order (should fix bluetooth daemon start)

* Thu Jun 17 2004 Stew Benedict <sbenedict@mandrakesoft.com> 0.21-3mdk
- add docs to -devel, dbus-monitor fixes from cvs (patch1)

* Sat Jun 05 2004 Laurent Montel <lmontel@mandrakesoft.com> 0.21-2mdk
- Rebuild

* Tue Apr 20 2004 Gtz Waschk <waschk@linux-mandrake.com> 0.21-1mdk
- fix qt build
- drop merged patch 1
- fix URL
- new version

